@@ -25,6 +25,7 @@
 #include "callbacks.h"
 #include "ifaces-list.h"
 #include "network-tool.h"
+#include "nm-integration.h"
 
 extern GstTool *tool;
 
@@ -268,23 +269,36 @@ get_iface_secondary_text (OobsIface *iface)
 {
   GString *str;
   gchar *text;
+  NMState state;
 
   str = g_string_new ("");
+  state = nm_integration_get_state (GST_NETWORK_TOOL (tool));
 
   if (!oobs_iface_get_configured (iface))
-    str = g_string_append (str, _("This network interface is not configured"));
+    {
+      if (!nm_integration_iface_supported (iface) ||
+	  state == NM_STATE_UNKNOWN ||
+	  state == NM_STATE_ASLEEP)
+	str = g_string_append (str, _("This network interface is not configured"));
+      else
+	str = g_string_append (str, _("Roaming mode enabled"));
+    }
   else if (OOBS_IS_IFACE_ETHERNET (iface))
     {
+      const gchar *config_method;
+
       if (OOBS_IS_IFACE_WIRELESS (iface))
 	g_string_append_printf (str, _("<b>Essid:</b> %s "),
 				oobs_iface_wireless_get_essid (OOBS_IFACE_WIRELESS (iface)));
 
-      if (oobs_iface_ethernet_get_configuration_method (OOBS_IFACE_ETHERNET (iface)) != OOBS_METHOD_DHCP)
+      config_method = oobs_iface_ethernet_get_configuration_method (OOBS_IFACE_ETHERNET (iface));
+
+      if (config_method && strcmp (config_method, "static") == 0)
 	g_string_append_printf (str, _("<b>Address:</b> %s <b>Subnet mask:</b> %s"),
 				oobs_iface_ethernet_get_ip_address (OOBS_IFACE_ETHERNET (iface)),
 				oobs_iface_ethernet_get_network_mask (OOBS_IFACE_ETHERNET (iface)));
       else
-	g_string_append_printf (str, _("<b>Address:</b> DHCP"));
+	g_string_append_printf (str, _("<b>Address:</b> %s"), config_method);
     }
   else if (OOBS_IS_IFACE_PLIP (iface))
     {
